# vs-iew

### PyPi package for quickly updating and installing all IEW packages.

<br>

<br><br>
## How to install

Install `vsiew` with the following command:

```sh
pip install vsiew
```

<br>

## How to use

Install all iew packages:
```sh
python -m vsiew
```

Install latest git version of all iew packages:
```sh
python -m vsiew latest
```

